@@ -1,9 +1,9 @@
 class PathNotExists(Exception):
-    def __init__(self, path):
+    def __init__(self, path: str):
         super(PathNotExists, self).__init__("{} does not exist".format(path))
 
 
 class NotOverwriting(Exception):
-    def __init__(self, file_):
+    def __init__(self, file_: str):
         super(NotOverwriting, self).__init__()
         self.file = file_
